# -*- coding: utf8 -*-

#-----------------------------------------
# This is a part of Collège 3D project.
# Author:       Pascal Peter
# Copyright:    (C) 2003-2016 Pascal Peter
# Licence:      GNU General Public Licence version 3
# Website:      http://pascal.peter.free.fr/
# Email:        pascal.peter at free.fr
#-----------------------------------------

"""
DESCRIPTION :
    Execution du splashscreen.
"""

# **************************************************
#       IMPORTATION DES MODULES UTILES
# **************************************************
import sys
import os
from time import time

import bge

scriptsDir = os.path.abspath(bge.logic.expandPath('//') + '..' + os.sep + 'scripts')
sys.path.insert(0, scriptsDir)
import utils, input_controller



# **************************************************
#       CONTRÔLES DU JEU
# **************************************************
scene = None
bge.logic.setExitKey(input_controller.QUIT_KEY)



# **************************************************
#       FONCTIONS UTILES
# **************************************************
def postDrawTexts():
    """
    affichage des textes.
    """
    utils.postDrawTexts()



# **************************************************
#       FONCTION PRINCIPALE
# **************************************************
def main():
    # ---------------------------------------------------------
    # RÉCUPÉRATION DE L'ÉTAT DU JEU
    # ---------------------------------------------------------
    if not('GAME' in bge.logic.globalDict):
        bge.logic.globalDict['GAME'] = {}
    state = bge.logic.globalDict['GAME'].get('state', '')
    if not(state in ('splash_first', 'splash_loop')):
        bge.logic.globalDict['GAME']['state'] = 'splash_first'

    # ---------------------------------------------------------
    # PREMIER LANCEMENT
    # ---------------------------------------------------------
    if bge.logic.globalDict['GAME']['state'] == 'splash_first':
        # on masque la souris :
        bge.render.showMouse(False)
        # valeurs initiales (lues depuis le fichier de config si existe) :
        utils.loadSettings()
        lang = bge.logic.globalDict['MENU']['lang']
        global scene
        scene = bge.logic.getCurrentScene()
        # affichage des textes :
        utils.loadFonts()
        scene.post_draw += [postDrawTexts]
        bge.logic.globalDict['TEXTS'] = {}
        utils.setText('progName', color=utils.colors['orange'], width=9, position=(0.15, 0.25))
        utils.setText('version', color=utils.colors['blue'], width=8, position=(0.18, 0.9))
        # initialisation des timers :
        bge.logic.globalDict['TEMP']['initialTime'] = time()
        bge.logic.globalDict['TEMP']['actualTime'] = 0
        bge.logic.globalDict['TEMP']['timeSpecific'] = {1: False, 2: False, 5: False}
        # initialisation terminée :
        bge.logic.globalDict['GAME']['state'] = 'splash_loop'

    # ---------------------------------------------------------
    # BOUCLE DES ÉVÉNEMENTS
    # ---------------------------------------------------------
    if bge.logic.globalDict['GAME']['state'] != 'splash_loop':
        return
    inputState = input_controller.inputManagement('splash')
    # pour faire un screencast :
    if inputState['SCREENSHOT']:
        utils.makeScreenshot()
    actualTime = int(round(time() - bge.logic.globalDict['TEMP']['initialTime']))
    if actualTime > bge.logic.globalDict['TEMP']['actualTime']:
        bge.logic.globalDict['TEMP']['actualTime'] = actualTime
        for i in bge.logic.globalDict['TEMP']['timeSpecific']:
            if (actualTime >= i) and not(bge.logic.globalDict['TEMP']['timeSpecific'][i]):
                bge.logic.globalDict['TEMP']['timeSpecific'][i] = True
                if i == 1:
                    utils.setText('progName', text=utils.PROGNAME)
                elif i == 2:
                    utils.setText('version', text=utils.PROGYEAR)
                elif i == 5:
                    bge.logic.globalDict['GAME']['state'] = 'splash_quit'
                    scene.replace('menu')


