#!/usr/bin/env python
# -*- coding: utf8 -*-

#-----------------------------------------
# This is a part of Collège 3D project.
# Author:       Pascal Peter
# Copyright:    (C) 2003-2016 Pascal Peter
# Licence:      GNU General Public Licence version 3
# Website:      http://pascal.peter.free.fr/
# Email:        pascal.peter at free.fr
#-----------------------------------------

"""
DESCRIPTION :
    programme serveur pour un jeu en réseau
    d'après Swinnen : http://inforef.be/swi/python.htm
"""

# importation des modules utiles :
from __future__ import print_function

import sys
import socket
import threading
import time



# **************************************************
#       POUR FONCTIONNER AVEC PYTHON 2.x OU 3.x
# **************************************************
PYTHONVERSION = sys.version_info[0] * 10 + sys.version_info[1]

def u(text):
    """
    retourne une version unicode de text
    """
    if PYTHONVERSION >= 30:
        try:
            if isinstance(text, str):
                return text
            else:
                return str(text)
        except:
            return text
    else:
        try:
            return unicode(text)
        except:
            if isinstance(text, str):
                return text.decode('utf-8')
            else:
                return text
    


# **************************************************
#       RÉCUPÉRATION DE L'IP DU POSTE
# **************************************************
def findMyIp():
    try:
        s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
        s.connect(('google.com', 80))
        myIp = s.getsockname()[0]
        s.close()
    except:
        myIp = 'localhost'
    return myIp



# **************************************************
#       PARAMÈTRES DE CONNEXION
# **************************************************
HOST = ''
for arg in sys.argv:
    if arg.split('=')[0] == 'HOST':
        HOST = arg.split('=')[1]
if HOST == '':
    HOST = findMyIp()
print('HOST :', HOST)
LAN_PORT = 5005
BUFFER = 1024



# **************************************************
#       DICTIONNAIRES DES CLIENTS CONNECTÉS
# **************************************************
CLIENTS = {'LIST': [], 'DATA': {}, 'LOCKED': False, 'TEXT': ''}

def updateClients(what='UPDATE', who=None, value=[None, None, None]):
    global CLIENTS
    if CLIENTS['LOCKED']:
        return False
    CLIENTS['LOCKED'] = True
    try:
        if what == 'UPDATE':
            if who in CLIENTS['LIST']:
                for i in range(3):
                    if value[i] != None:
                        CLIENTS['DATA'][who][i] = value[i]
            else:
                CLIENTS['LIST'].append(who)
                CLIENTS['DATA'][who] = value
        elif what == 'DELETE':
            if who in CLIENTS['LIST']:
                CLIENTS['LIST'].remove(who)
            del CLIENTS['DATA'][who]

        newClientsText = 'CLIENTSø'
        for client in CLIENTS['LIST']:
            name = CLIENTS['DATA'][client][1]
            if name != '':
                color = CLIENTS['DATA'][client][2]
                newClientsText = '{0}{1}#{2}#{3}ø'.format(newClientsText, client, name, color)
        if newClientsText != CLIENTS['TEXT']:
            CLIENTS['TEXT'] = newClientsText
            print(CLIENTS['LIST'])#, CLIENTS['TEXT'])
    finally:
        CLIENTS['LOCKED'] = False
        return True



# **************************************************
#       THREAD DE GESTION DES CLIENTS
# **************************************************
SERVER_LAST = ''

class ThreadClient(threading.Thread):
    """
    dérivation d'un objet thread pour gérer la connexion avec un client.
    Seul le thread "SERVER" pourra modifier les variables globales
    """
    def __init__(self, connexion, parent=None):
        threading.Thread.__init__(self)
        self.connexion = connexion
        self.parent = parent
        self.time = 0

    def run(self):
        # Dialogue avec le client :
        # Chaque thread possède un nom
        threadClientName = self.getName()
        if threadClientName == 'Thread-1':
            clientName = 'SERVER'
        else:
            clientName = ''
        clients = {}
        try:
            while True:
                time.sleep(0.01)
                if clientName == 'SERVER':
                    global SERVER_LAST
                # on récupère le dico CLIENTS :
                if not(CLIENTS['LOCKED']):
                    clients = {}
                    for client in CLIENTS['LIST']:
                        data = CLIENTS['DATA'][client]
                        clients[client] = [data[0], data[1], data[2]]
                # on récupère le nom du client si besoin :
                if clientName == '':
                    client = clients.get(threadClientName, None)
                    if client != None:
                        clientName = client[1]
                # on récupère received_message (le message reçu) :
                try:
                    if PYTHONVERSION >= 30:
                        received_message = self.connexion.recv(BUFFER).decode('Utf8')
                    else:
                        received_message = u(self.connexion.recv(BUFFER))
                except:
                    received_message = 'END'
                # si on doit quitter :
                if not(received_message) or (received_message.upper() == 'END'):
                    break
                # mise en forme de la réponse (reply) :
                reply = u('{0}ø{1}ø{2}').format(threadClientName, clientName, received_message)
                actualTime = int(time.time() - self.time)
                if actualTime > 1:
                    self.time = int(time.time())
                # on traite le contenu du message reçu :
                if received_message.upper() == 'TEST':
                    others = []
                    for client in clients:
                        user = clients[client][1]
                        if (user != '') and not(user in others):
                            others.append(user)
                    msgOthers = 'OTHERSø'
                    for other in others:
                        msgOthers = '{0}{1}ø'.format(msgOthers, other)
                    self.sendMessage(threadClientName, msgOthers)
                else:
                    if 'CONNECT' in received_message:
                        if not(threadClientName in clients):
                            clients[threadClientName] = [self.connexion, '', '']
                        try:
                            clients[threadClientName][1] = received_message.split('ø')[1]
                            clientName = clients[threadClientName][1]
                            updateClients(
                                who=threadClientName, value=[self.connexion, clientName, None])
                        except:
                            pass
                    elif 'LOOP' in received_message:
                        try:
                            received_name = received_message.split('ø')[1]
                            received_color = received_message.split('ø')[3]
                            if not(threadClientName in clients):
                                clients[threadClientName] = [self.connexion, '', '']
                            if clients[threadClientName][1] == '':
                                clientName = received_name
                                clients[threadClientName][1] = received_name
                            elif clients[threadClientName][2] != received_color:
                                clients[threadClientName][2] = received_color
                            updateClients(
                                who=threadClientName, 
                                value=[self.connexion, clientName, received_color])
                        except:
                            pass
                    elif clientName == 'SERVER':
                        if SERVER_LAST != received_message:
                            SERVER_LAST = received_message
                            print('SERVER_LAST :', SERVER_LAST)
                    # Faire suivre le message à tous les autres clients :
                    reply = u('{0}&{1}&{2}&').format(reply, CLIENTS['TEXT'], SERVER_LAST)
                    for client in clients:
                        # ne pas le renvoyer à l'émetteur
                        if client != threadClientName:
                            self.sendMessage(client, reply)

            # Fermeture de la connexion :
            # on avertit les autres :
            reply = '{0}ø{1}øDISCONNECT'.format(threadClientName, clientName)
            for client in clients:
                if client != threadClientName:
                    self.sendMessage(client, reply)
            # couper la connexion côté serveur
            self.connexion.close()
        finally:
            # on supprime le thread du dictionnaire
            updateClients(what='DELETE', who=threadClientName)
            print('{0}ø{1}øDISCONNECT'.format(threadClientName, clientName))

    def sendMessage(self, client, message):
        try:
            connexion = CLIENTS['DATA'][client][0]
            connexion.send(message.encode('Utf8'))
        except:
            updateClients(what='DELETE', who=client)



# **************************************************
#       CLASSE SERVEUR
# **************************************************
class LanServer():
    def __init__(self, host=HOST):
        # Initialisation du serveur - Mise en place du socket :
        self.mySocket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        self.mySocket.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
        try:
            self.mySocket.bind((host, LAN_PORT))
        except socket.error:
            print('SERVER SOCKET ERROR')
            return None
        print('SERVER READY ...')
        self.mySocket.listen(32)

    def loop(self):
        connexion, adresse = self.mySocket.accept()
        # Créer un nouvel objet thread pour gérer la connexion :
        threadClient = ThreadClient(connexion, self)
        threadClient.start()
        # Mémoriser la connexion dans le dictionnaire :
        # identifiant du thread
        threadClientName = threadClient.getName()
        updateClients(who=threadClientName, value=[connexion, '', ''])



# **************************************************
#       PROGRAMME PRINCIPAL
# **************************************************
def main():
    lanServer = LanServer()
    while True:
        lanServer.loop()


if __name__ == "__main__":
    main()
