# -*- coding: utf8 -*-

#-----------------------------------------
# This is a part of Collège 3D project.
# Author:       Pascal Peter
# Copyright:    (C) 2003-2016 Pascal Peter
# Licence:      GNU General Public Licence version 3
# Website:      http://pascal.peter.free.fr/
# Email:        pascal.peter at free.fr
#-----------------------------------------

"""
DESCRIPTION :
    Définitions des jeux, niveaux et missions.
        * un jeu est composé de niveaux
        * un niveau est composé de missions

    Bien respecter la structure du fichier si on veut le modifier.
    Pour chaque jeu, on définit :
        * d'abord les missions (s'il y en a)
        * ensuite les niveaux
    Enfin on définit à la fin du fichier :
        * la liste des jeux
        * la liste des niveaux pour les jeux qui en ont
        * la liste des positions initiales pour les jeux qui en ont

    STRUCTURE D'UNE MISSION :
        une mission est un dictionnaire.
        Seuls les éléments nécessaires à la mission doivent être indiqués.
        M_Nom = {'text': 'texte', 'cible': (cible), 'time': [temps], 'hook':(objet)}
            * M_Nom :   nom de la mission (ici en interne)
            * text :    le texte affiché (ordre à executer par le joueur)
                        sera traduit via le fichier scenarios.csv
                        EXEMPLE : 'text': 'affiches5'
            * cible :   si renseigné, il y a une cible à atteindre, 
                        avec sa position (ou une liste de positions), 
                        le rayon de détection, le nom de l'objet à afficher
                        par exemple, 'cible': ((10, 36, 10), 3, 'objets/divers', 'cible')
                        indique qu'il y a une cible
                        dont la position est (10, 36, 10) et qu'on l'a atteinte si on
                        se trouve à moins de 3m
                        Le fichier sera objets/divers.blend et l'objet s'appelle cible.
                        EXEMPLES : 
                            'cible': ((10, 36, 10), 3, 'objets/divers', 'cible')
                            'cible': (((23, 2, 7.8), (11, 13, 11.6),), 3, 'objets/divers', 'cible')
            * time :    le temps est-il limité, sa valeur, on affiche la cible lorsqu'il reste
                        par exemple, [60, 20] indique que le temps est limité
                        à 60s, et que la cible sera visible 20s avant la fin
            * hook :    si le personnage tient un objet à la main pendant la mission
                        EXEMPLE : 'hook':('objets/saisons', 'bouquet')
            * head :    si le personnage porte un objet sur la tête
                        EXEMPLE : 'hook':('objets/saisons', 'bouquet')
            * result :  si un objet est créé à la fin
                        EXEMPLE : 'result':('objets/saisons', 'bouquet')

    STRUCTURE D'UN NIVEAU :
        L_Nom =    {'name':'nom du niveau', 
                    'initialPositions':(positions initiales), 
                    'missions':[liste des missions],
                    'random':True/False,
                    'weather':'météo du niveau']
            * L_Nom :   nom du niveau (ici en interne)
            * name :     le nom du niveau
                        si vide, c'est qu'il succède au précédent et n'est pas un vrai niveau.
                        Par exemple, dans le jeu "découvrir", chaque niveau est fait de 2 parties
                        la première avec la cible visible, la seconde sans.
                        Cela permet de sortir les missions au hasard tout en ne mélangeant pas
                        les 2 parties du niveau.
            * initialPositions : listes des positions où le personnage pourra apparaitre
                        au début du niveau. Il peut y en avoir plusieurs.
                        par exemple, ((13, 47, 12),) indique une seule position
                        tandis que ((13, 47, 12), (17, 45, 12)) en indique 2.
                        Si non renseigné, le joueur reste où il était.
            * missions : la liste des missions du niveau
                        utilise les noms internes des missions
                        par exemple, [Discover_M_Portail1, Discover_M_Velos1, Discover_M_PorteEntree1]
            * random : True ou False
                        si True, les missions sont proposées au hasard
                        si False, elles sont effectuées dans l'ordre de la liste
            * weather : la météo du niveau ('' par défaut)
"""



# @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
# @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
# 
#              JEU : DÉCOUVRIR LE COLLÈGE (VISITE DES ÉLÈVES DE CM2)
#                       (DÉCLARATION DES MISSIONS ET NIVEAUX)
# 
# @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
# @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@

# **************************************************
#       LES MISSIONS DU JEU DÉCOUVRIR
#       (doivent être définies en premier)
# **************************************************
Discover_M_Portail1 = {
    'text': 'Portail',
    'cible': ((10, 36, 10), 3, 'objets/divers', 'cible'),
    'time': [30, 30]}
Discover_M_Portail2 = {
    'text': 'Portail',
    'cible': ((10, 36, 10), 3, 'objets/divers', 'cible'),
    'time': [60, 20]}
Discover_M_Velos1 = {
    'text': 'Velos',
    'cible': ((-3, 38, 10), 5, 'objets/divers', 'cible'),
    'time': [30, 30]}
Discover_M_Velos2 = {
    'text': 'Velos',
    'cible': ((-3, 38, 10), 5, 'objets/divers', 'cible'),
    'time': [60, 20]}
Discover_M_PorteEntree1 = {
    'text': 'PorteEntree',
    'cible': ((11, 21, 10), 3, 'objets/divers', 'cible'),
    'time': [30, 30]}
Discover_M_PorteEntree2 = {
    'text': 'PorteEntree',
    'cible': ((11, 21, 10), 3, 'objets/divers', 'cible'),
    'time': [60, 20]}

Discover_M_Fontaines1 = {
    'text': 'Fontaines', 
    'cible': ((13, 1.5, 10), 3, 'objets/divers', 'cible'), 
    'time': [30, 30]}
Discover_M_Fontaines2 = {
    'text': 'Fontaines', 
    'cible': ((13, 1.5, 10), 3, 'objets/divers', 'cible'), 
    'time': [60, 20]}
Discover_M_Telephon1 = {
    'text': 'Telephon',
    'cible': ((6.5, 19.5, 10), 3, 'objets/divers', 'cible'),
    'time': [30, 30]}
Discover_M_Telephon2 = {
    'text': 'Telephon',
    'cible': ((6.5, 19.5, 10), 3, 'objets/divers', 'cible'),
    'time': [60, 20]}
Discover_M_Accueil1 = {
    'text': 'Accueil',
    'cible': ((5.8, 10.2, 10), 3, 'objets/divers', 'cible'),
    'time': [30, 30]}
Discover_M_Accueil2 = {
    'text': 'Accueil',
    'cible': ((5.8, 10.2, 10), 3, 'objets/divers', 'cible'),
    'time': [60, 20]}
Discover_M_SortieRefectoire1 = {
    'text': 'SortieRefectoire',
    'cible': ((17.5, 18, 10.6), 3, 'objets/divers', 'cible'),
    'time': [30, 30]}
Discover_M_SortieRefectoire2 =  {
    'text': 'SortieRefectoire',
    'cible': ((17.5, 18, 10.6), 3, 'objets/divers', 'cible'),
    'time': [60, 20]}
  
Discover_M_Pingpong1 = {
    'text': 'Pingpong',
    'cible': ((15, -21, 9), 1.5, 'objets/divers', 'cible'),
    'time': [30, 30]}
Discover_M_Pingpong2 = {
    'text': 'Pingpong',
    'cible': ((15, -21, 9), 1.5, 'objets/divers', 'cible'),
    'time': [60, 20]}
Discover_M_Tour1 = {
    'text': 'Tour',
    'cible': ((33, -39, 11), 4, 'objets/divers', 'cible'),
    'time': [30, 30]}
Discover_M_Tour2 = {
    'text': 'Tour',
    'cible': ((33, -39, 11), 4, 'objets/divers', 'cible'),
    'time': [60, 20]}
Discover_M_Cantine1 = {
    'text': 'Cantine',
    'cible': ((23.4, -5.9, 10), 3, 'objets/divers', 'cible'),
    'time': [30, 30]}
Discover_M_Cantine2 = {
    'text': 'Cantine',
    'cible': ((23.4, -5.9, 10), 3, 'objets/divers', 'cible'),
    'time': [60, 20]}

Discover_M_A_Hall1 = {
    'text': 'A_Hall',
    'cible': ((-14, 8, 9), 4, 'objets/divers', 'cible'),
    'time': [45, 45]}
Discover_M_A_Hall2 = {
    'text': 'A_Hall',
    'cible': ((-14, 8, 9), 4, 'objets/divers', 'cible'),
    'time': [60, 20]}
Discover_M_A_Escaliers1 = {
    'text': 'A_Escaliers',
    'cible': ((-42, 11, 8), 4, 'objets/divers', 'cible'),
    'time': [45, 45]}
Discover_M_A_Escaliers2 = {
    'text': 'A_Escaliers',
    'cible': ((-42, 11, 8), 4, 'objets/divers', 'cible'),
    'time': [60, 20]}
Discover_M_B_Entree1 = {
    'text': 'B_Entree',
    'cible': ((-34, -14, 8), 4, 'objets/divers', 'cible'),
    'time': [45, 45]}
Discover_M_B_Entree2 = {
    'text': 'B_Entree',
    'cible': ((-34, -14, 8), 4, 'objets/divers', 'cible'),
    'time': [60, 20]}
Discover_M_C_CDI1 = {
    'text': 'C_CDI',
    'cible': ((-5, -21, 9), 4, 'objets/divers', 'cible'),
    'time': [45, 45]}
Discover_M_C_CDI2 = {
    'text': 'C_CDI',
    'cible': ((-5, -21, 9), 4, 'objets/divers', 'cible'),
    'time': [60, 20]}
Discover_M_C_Techno1 = {
    'text': 'C_Techno',
    'cible': ((5, -46, 9), 4, 'objets/divers', 'cible'),
    'time': [45, 45]}
Discover_M_C_Techno2 = {
    'text': 'C_Techno',
    'cible': ((5, -46, 9), 4, 'objets/divers', 'cible'),
    'time': [60, 20]}

# **************************************************
#       LES NIVEAUX DU JEU DÉCOUVRIR
#       (doivent être définis après les missions)
# **************************************************
Discover_L_BeforeEnter1 = {
    'name': 'BeforeEnter', 
    'initialPositions': ((13, 47, 12),), 
    'missions': [Discover_M_Portail1, Discover_M_Velos1, Discover_M_PorteEntree1],
    'random' : True, 
    'weather': 'good weather'}
Discover_L_BeforeEnter2 = {
    'name': '', 
    'missions': [Discover_M_Portail2, Discover_M_Velos2, Discover_M_PorteEntree2],
    'random' : True, 
    'weather': 'good weather'}

Discover_L_TheHall1 = {
    'name': 'TheHall', 
    'initialPositions': ((12, 12, 10),), 
    'missions': [Discover_M_Fontaines1, Discover_M_Accueil1, Discover_M_SortieRefectoire1],
    'random' : True, 
    'weather': 'good weather'}
Discover_L_TheHall2 = {
    'name': '', 
    'missions': [Discover_M_Fontaines2, Discover_M_Accueil2, Discover_M_SortieRefectoire2],
    'random' : True, 
    'weather': 'good weather'}

Discover_L_Tour1 = {
    'name': 'NearTower', 
    'initialPositions': ((13, 1, 11),), 
    'missions': [Discover_M_Pingpong1, Discover_M_Tour1, Discover_M_Cantine1],
    'random' : True, 
    'weather': 'good weather'}
Discover_L_Tour2 = {
    'name': '', 
    'missions': [Discover_M_Pingpong2, Discover_M_Tour2, Discover_M_Cantine2],
    'random' : True, 
    'weather': 'good weather'}

Discover_L_Batiments1 = {
    'name': 'Batiments', 
    'initialPositions': ((16, -11, 10),), 
    'missions': [
        Discover_M_A_Hall1, Discover_M_A_Escaliers1, Discover_M_B_Entree1, 
        Discover_M_C_CDI1, Discover_M_C_Techno1],
    'random' : True, 
    'weather': 'good weather'}
Discover_L_Batiments2 = {
    'name': '', 
    'missions': [
        Discover_M_A_Hall2, Discover_M_A_Escaliers2, Discover_M_B_Entree2, 
        Discover_M_C_CDI2, Discover_M_C_Techno2],
    'random' : True, 
    'weather': 'good weather'}



# @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
# @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
# 
#                       JEU : LE COLLÈGE A 10 ANS
#                       (DÉCLARATION DES MISSIONS ET NIVEAUX)
# 
# @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
# @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@

# **************************************************
#       LES MISSIONS DU JEU 10
#       (doivent être définies en premier)
# **************************************************
# AFFICHES :
Ten_M_affiches1 = {
    'text': 'affiches1',
    'cible': ((23, -3, 7.8), 3, 'objets/divers', 'cible'),
    'time': [120, 0],
    'hook':('objets/10ans', 'sceau'),
    'result': ('objets/10ans', 'affiche1')}
Ten_M_affiches2 = {
    'text': 'affiches2',
    'cible': ((-3, -22, 7.3), 3, 'objets/divers', 'cible'),
    'time': [120, 0],
    'hook':('objets/10ans', 'sceau'),
    'result': ('objets/10ans', 'affiche2')}
Ten_M_affiches3 = {
    'text': 'affiches3',
    'cible': ((6, 8, 7.8), 3, 'objets/divers', 'cible'),
    'time': [120, 0],
    'hook':('objets/10ans', 'sceau'),
    'result': ('objets/10ans', 'affiche3')}
Ten_M_affiches4 = {
    'text': 'affiches4',
    'cible': ((-17, 8, 7.3), 3, 'objets/divers', 'cible'),
    'time': [120, 0],
    'hook':('objets/10ans', 'sceau'),
    'result': ('objets/10ans', 'affiche4')}
Ten_M_affiches5 = {
    'text': 'affiches5',
    'cible': ((10, 36, 10), 3, 'objets/divers', 'cible'),
    'time': [120, 0],
    'hook':('objets/10ans', 'sceau'),
    'result': ('objets/10ans', 'affiche5')}

# CADEAUX :
Ten_M_cadeaux1 = {
    'text': 'cadeaux1',
    'cible': ((-36, 23, 9.5), 3, 'objets/10ans', 'cadeau1'),
    'time': [120, 120]}
Ten_M_cadeaux2 = {
    'text': 'cadeaux2',
    'cible': (((-43, 23, 9.5), (-29, 24, 9.5),), 3, 'objets/10ans', 'cadeau2'),
    'time': [120, 120]}
Ten_M_cadeaux3 = {
    'text': 'cadeaux3',
    'cible': (((-29, 6, 9.5), (-29, 17, 9.5),), 3, 'objets/10ans', 'cadeau3'),
    'time': [120, 120]}
Ten_M_cadeaux4 = {
    'text': 'cadeaux4',
    'cible': (((-14, 6, 11), (-22, 7, 11),), 3, 'objets/10ans', 'cadeau4'),
    'time': [120, 120]}
Ten_M_cadeaux5 = {
    'text': 'cadeaux5','cible': ((-8, 15, 11), 3, 'objets/10ans', 'cadeau5'),
    'time': [120, 120]}
Ten_M_cadeaux9 = {
    'text': 'cadeaux9',
    'cible': ((28, 21, 8.2), 3, 'objets/10ans', 'level2'),
    'time': [120, 0],
    'hook':('objets/10ans', 'cadeaux')}

# GÂTEAU :
Ten_M_gateau1 = {
    'text': 'gateau1',
    'cible': (
        ((11, 13, 11.6), (-13, 10, 14), (-21, 9, 14), (-31, -6, 9.5), (-44, -16, 12.7), (-9, -31, 14),), 
        3, 
        'objets/10ans', 
        'gateau'),
    'time': [120, 120]}
Ten_M_gateau2 = {
    'text': 'gateau2',
    'cible': ((28, 21, 8.2), 3, 'objets/10ans', 'level3'),
    'time': [120, 120],
    'hook':('objets/10ans', 'gateau_hook')}

# BOUGIES :
Ten_M_bougies1 = {
    'text': 'bougies1',
    'cible': (((18, -12, 7.3), (33, -54, 8.8), (-12, 1, 7.2), (-25, -8, 5.9), (-30, -1, 6.1),), 2, 
             'objets/10ans', 'bougies'),
    'time': [120, 120]}
Ten_M_bougies2 = {
    'text': 'bougies2',
    'cible': (((33, -30, 8.8), (0, -17, 7.4), (-8, -8, 7), (-18, -12, 6.6),), 2, 
             'objets/10ans', 'bougies'),
    'time': [120, 120]}
Ten_M_bougies3 = {
    'text': 'bougies3',
    'cible': (((-15, -26, 10.4),), 3, 
             'objets/10ans', 'briquet'),
    'time': [120, 120]}
Ten_M_bougies4 = {
    'text': 'bougies4',
    'cible': ((28, 21, 8.2), 3, 'objets/10ans', 'level4'),
    'time': [120, 120],
    'hook':('objets/10ans', 'bougies_hook')}

# CHAPEAU :
Ten_M_chapeau1a = {
    'text': 'chapeau1',
    'cible': (((-14, 8, 7.3), (-46, 9, 6.1), (33, -20, 7.9), (8, -46, 7.2),), 3, 
             'objets/10ans', 'chapeau1'),
    'time': [120, 120]}
Ten_M_chapeau2a = {
    'text': 'chapeau2',
    'cible': ((28, 21, 8.2), 3, 'objets/10ans', 'level5'),
    'time': [120, 120],
    'head': ('objets/10ans', 'chapeau1_head')}
Ten_M_chapeau1b = {
    'text': 'chapeau1',
    'cible': (((-14, 8, 7.3), (-46, 9, 6.1), (33, -20, 7.9), (8, -46, 7.2),), 3, 
             'objets/10ans', 'chapeau2'),
    'time': [120, 120]}
Ten_M_chapeau2b = {
    'text': 'chapeau2',
    'cible': ((28, 21, 8.2), 3, 'objets/10ans', 'level5'),
    'time': [120, 120],
    'head': ('objets/10ans', 'chapeau2_head')}

# **************************************************
#       LES NIVEAUX DU JEU 10 ANS
#       (doivent être définis après les missions)
# **************************************************
Ten_L_affiches = {
    'name': 'L_affiches', 
    'initialPositions': ((10, 25, 9),), 
    'missions': [
        Ten_M_affiches1, Ten_M_affiches2, Ten_M_affiches3, Ten_M_affiches4, Ten_M_affiches5],
    'random' : True, 
    'weather': 'good weather'}
Ten_L_cadeaux = {
    'name': 'L_cadeaux', 
    'initialPositions': ((-44, 6, 7),), 
    'missions': [Ten_M_cadeaux1, Ten_M_cadeaux2, Ten_M_cadeaux3, Ten_M_cadeaux4, Ten_M_cadeaux5,
                 Ten_M_cadeaux9],
    'weather': 'good weather'}
Ten_L_gateau = {
    'name': 'L_gateau', 
    'initialPositions': ((10, 34, 9),), 
    'missions': [Ten_M_gateau1, Ten_M_gateau2],
    'weather': 'good weather'}
Ten_L_bougies = {
    'name': 'L_bougies', 
    'initialPositions': ((16, -29, 10),), 
    'missions': [Ten_M_bougies1, Ten_M_bougies2, Ten_M_bougies3, Ten_M_bougies4],
    'weather': 'good weather'}
Ten_L_chapeau = {
    'name': 'L_chapeau', 
    'initialPositions': ((11, 24, 8.9),), 
    'missions': ([Ten_M_chapeau1a, Ten_M_chapeau2a], [Ten_M_chapeau1b, Ten_M_chapeau2b]),
    'weather': 'good weather'}



# @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
# @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
# 
#                       JEU : LE COLLÈGE AU COURS DES SAISONS
#                       (DÉCLARATION DES MISSIONS ET NIVEAUX)
# 
# @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
# @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@

# **************************************************
#       LES MISSIONS DU JEU SAISONS
#       (doivent être définies en premier)
# **************************************************
# PRINTEMPS :
Seasons_M_Spring1a = {
    'text': 'Spring1',
    'cible': (((-30, -36, 6), (-55, -60, 6), (-38, -72, 6),), 3, 
             'objets/saisons', 'fleur'),
    'time': [120, 120]}
Seasons_M_Spring1b = {
    'cible': (((-40, -36, 6), (-45, -60, 6), (-28, -72, 6),), 3, 
             'objets/saisons', 'fleur'),
    'time': [20, 20]}
Seasons_M_Spring1c = {
    'cible': (((-30, -41, 6), (-55, -65, 6), (-38, -77, 6),), 3, 
             'objets/saisons', 'fleur'),
    'time': [20, 20]}
Seasons_M_Spring2 = {
    'text': 'Spring2',
    'cible': ((-33, 11, 8), 3, 'objets/saisons', 'herbier'),
    'time': [60, 60], 
    'hook':('objets/saisons', 'bouquet')}

# ÉTÉ :
Seasons_M_Summer1 = {
    'text': 'Summer1',
    'cible': (
        ((35, -39, 8.4), (13, -21, 7.8), (-2, -7, 7.4), (-11, -7, 7.4), (-23, -5, 6.4),), 3, 
        'objets/saisons', 'arrosoir'),
    'time': [60, 60]}
Seasons_M_Summer2 = {
    'text': 'Summer2',
    'cible': ((13, 1.5, 7.4), 3, 'objets/saisons', 'repere_ici'),
    'time': [60, 5],
    'hook':('objets/saisons', 'arrosoir_main')}
Seasons_M_Summer3 = {
    'text': 'Summer3',
    'cible': ((19, -18, 7.4), 3, 'objets/saisons', 'repere_ici'),
    'time': [60, 60],
    'hook':('objets/saisons', 'arrosoir_main')}
Seasons_M_Summer4 = {
    'text': 'Summer4',
    'cible': ((13, -25, 7.4), 3, 'objets/saisons', 'repere_ici'),
    'time': [60, 60],
    'hook':('objets/saisons', 'arrosoir_main')}
Seasons_M_Summer5 = {
    'text': 'Summer5',
    'cible': ((13, -37, 7.4), 3, 'objets/saisons', 'repere_ici'),
    'time': [60, 60],
    'hook':('objets/saisons', 'arrosoir_main')}

# AUTOMNE :
Seasons_M_Autumn1 = {
    'text': 'Autumn1',
    'cible': (((15, -22, 7.4), (36, -33, 8.4), (-3, -8, 7.4), (-21, -13, 6.4),), 3, 
             'objets/saisons', 'tas_de_feuilles'),
    'time': [60, 60], 
    'hook':('objets/saisons', 'pelle')}
Seasons_M_Autumn2a = {
    'text': 'Autumn2',
    'cible': (((15, -33, 7.4), (32, -44, 8.4), (-8, -12, 7.4), (-22, -2, 6.4),), 3, 
             'objets/saisons', 'tas_de_feuilles'),
    'time': [60, 60], 
    'hook':('objets/saisons', 'pelle')}
Seasons_M_Autumn2b = {
    'text': 'Autumn2',
    'cible': (((15, -22, 7.4), (36, -33, 8.4), (-3, -8, 7.4), (-21, -13, 6.4),), 3, 
             'objets/saisons', 'tas_de_feuilles'),
    'time': [60, 60], 
    'hook':('objets/saisons', 'pelle')}

# HIVER :
Seasons_M_Winter1 = {
    'text': 'Winter1',
    'cible': ((13, -20, 8), 3, 'objets/saisons', 'tas_de_neige'),
    'time': [60, 60]}
Seasons_M_Winter2 = {
    'text': 'Winter2',
    'cible': ((10, -34, 8), 3, 'objets/saisons', 'tas_de_neige'),
    'time': [60, 60]}
Seasons_M_Winter3 = {
    'text': 'Winter3',
    'cible': ((13, -20, 8), 3, 'objets/saisons', 'tas_de_neige'),
    'time': [60, 60]}
Seasons_M_Winter4 = {
    'text': 'Winter4',
    'cible': ((26, 21, 9), 3, 'objets/saisons', 'carotte'),
    'time': [60, 60]}
Seasons_M_Winter5 = {
    'text': 'Winter5',
    'cible': ((20, -17, 7.5), 3, 'objets/saisons', 'branche'),
    'time': [60, 60]}
Seasons_M_Winter6 = {
    'text': 'Winter6',
    'cible': ((20, -30, 7.5), 3, 'objets/saisons', 'branche'),
    'time': [60, 60]}
Seasons_M_Winter7 = {
    'text': 'Winter7',
    'cible': ((28, -38, 9), 3, 'objets/saisons', 'cailloux'),
    'time': [60, 60]}
Seasons_M_Winter8 = {
    'text': 'Winter8',
    'cible': ((15, -20, 7.5), 3, 'objets/saisons', 'bonhomme_neige'),
    'time': [60, 60]}

# **************************************************
#       LES NIVEAUX DU JEU SAISONS
#       (doivent être définis après les missions)
# **************************************************
Seasons_L_Spring = {
    'name': 'Spring', 
    'initialPositions': ((13, 47, 12),), 
    'missions': [
        Seasons_M_Spring1a, 
        Seasons_M_Spring1b, Seasons_M_Spring1c, Seasons_M_Spring1b, 
        Seasons_M_Spring1c, Seasons_M_Spring1b,
        Seasons_M_Spring2],
    'weather': 'rain'}
Seasons_L_Summer = {
    'name': 'Summer', 
    'initialPositions': ((13, 47, 12),), 
    'missions': [
        Seasons_M_Summer1, Seasons_M_Summer2, Seasons_M_Summer3, 
        Seasons_M_Summer2, Seasons_M_Summer4, Seasons_M_Summer2, Seasons_M_Summer5],
    'weather': 'good weather'}
Seasons_L_Autumn = {
    'name': 'Autumn', 
    'initialPositions': ((13, 47, 12),), 
    'missions': [
        Seasons_M_Autumn1, 
        Seasons_M_Autumn2a, Seasons_M_Autumn2b, Seasons_M_Autumn2a, Seasons_M_Autumn2b],
    'weather': 'dead leaves'}
Seasons_L_Winter = {
    'name': 'Winter', 
    'initialPositions': ((13, 47, 12),), 
    'missions': [
        Seasons_M_Winter1, Seasons_M_Winter2, Seasons_M_Winter3, Seasons_M_Winter4, 
        Seasons_M_Winter5, Seasons_M_Winter6, Seasons_M_Winter7, Seasons_M_Winter8],
    'weather': 'snow'}



# @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
# @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
# 
#                               JEU : L'EXPOSITION
#                       (DÉCLARATION DES MISSIONS ET NIVEAUX)
# 
# @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
# @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@

# **************************************************
#       LES MISSIONS DU JEU EXPOSITION
#       (doivent être définies en premier)
# **************************************************
Exhibition_M_Tour = {
    'text': 'ExhibitionTour',
    'cible': ((37.5, -41.5, 10), 1, 'objets/divers', 'cible2'),
    }
Exhibition_M_Expo = {
    'cible': ((33, -41, -2), 2, 'objets/divers', 'cible2'),
    }

# **************************************************
#       LES NIVEAUX DU JEU EXPOSITION
#       (doivent être définis après les missions)
# **************************************************
Exhibition_L_Tour = {
    'name': 'Exhibition_L_Tour', 
    'initialPositions': ((13, 47, 12),), 
    'missions': [Exhibition_M_Tour,],
    }
Exhibition_L_Expo = {
    'name': '', 
    'initialPositions': ((37, -40, 0),), 
    'missions': [Exhibition_M_Expo,],
    'weather': 'good weather'}



# @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
# @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
# 
#                       LISTE DES JEUX ET AUTRES TRUCS
#                      (doivent être définis en dernier)
# 
# @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
# @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@

# la liste des jeux :
games = (
    'Discover_the_college', 
    '2003-2013', 
    'During_seasons', 
    'Free_visit', 
    'Exhibition', 
    'LAN')

# pour les jeux ayant des niveaux, la liste des niveaux :
levels = {
    'Discover_the_college': [
        Discover_L_BeforeEnter1, Discover_L_BeforeEnter2, 
        Discover_L_TheHall1, Discover_L_TheHall2, 
        Discover_L_Tour1, Discover_L_Tour2,
        Discover_L_Batiments1, Discover_L_Batiments2,
        ], 
    '2003-2013': [Ten_L_affiches, Ten_L_cadeaux, Ten_L_gateau, Ten_L_bougies, Ten_L_chapeau,], 
    'During_seasons': [Seasons_L_Spring, Seasons_L_Summer, Seasons_L_Autumn, Seasons_L_Winter,], 
    'Exhibition': [Exhibition_L_Tour, Exhibition_L_Expo,], 
    }

# pour certains jeux, les positions initiales possibles.
# Le personnage apparaitra dans l'une des positions, au hasard :
initialPositions = {
    'Free_visit': (
        (13, 47, 12), (10, 34, 12), (6, 30, 11), # entrée
        ), 
    'During_seasons': (
        (12, 12, 10), (12, 6, 10), (8, 13, 10), # hall
        ), 
    'LAN': (
        (13, 47, 12), (10, 34, 12), (6, 30, 11), # entrée
        (12, 12, 10), (12, 6, 10), (8, 13, 10), # hall
        (16, -9, 10), (16, -21, 10), (28, -35, 12), # tour
        (-2, -7, 10), (-11, -7, 10), (-23, -5, 9), # cour
        ), 
    }

# pour certains jeux, la scène à afficher lorsque le jeu est terminé :
wonScenes = {
    'Exhibition': 'menu', 
    }


